package cz.cvut.and.tutorial06;

import android.content.ContentProvider;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.UriMatcher;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteQueryBuilder;
import android.net.Uri;
import android.text.TextUtils;

public class DictionaryProvider extends ContentProvider {
	public static final String AUTHORITY = "cz.cvut.and.tutorial06.dictionaryprovider";
	public static final Uri CONTENT_URI = Uri.parse("content://" + AUTHORITY);

	private static final int WORDS_ALL_ROWS = 1;
	private static final int WORDS_SINGLE_ROW = 2;

	private static final UriMatcher uriMatcher = new UriMatcher(
			UriMatcher.NO_MATCH);

	static {
		uriMatcher.addURI(AUTHORITY, "words", WORDS_ALL_ROWS);
		uriMatcher.addURI(AUTHORITY, "words/#", WORDS_SINGLE_ROW);
	}

	private DatabaseHelper mDatabaseHelper;

	@Override
	public boolean onCreate() {
		mDatabaseHelper = new DatabaseHelper(getContext());
		return true;
	}

	@Override
	public int delete(Uri uri, String selection, String[] selectionArgs) {
		String table = null;
		switch (uriMatcher.match(uri)) {
		case WORDS_SINGLE_ROW:
			long id = ContentUris.parseId(uri);
			if(TextUtils.isEmpty(selection)) {
				selection = "";
			}
			selection += Contract.Dictionary.COLUMN_ID + "=" + id;
		case WORDS_ALL_ROWS:
			table = Contract.Dictionary.TABLE_NAME;
			break;
		default:
			throw new IllegalArgumentException("Unsupported uri: " + uri);
		}
		SQLiteDatabase db = mDatabaseHelper.getWritableDatabase();
		int count = db.delete(table, selection, selectionArgs);
		if (count > 0) {
			getContext().getContentResolver().notifyChange(uri, null);
		}
		return count;
	}

	@Override
	public String getType(Uri uri) {
		switch (uriMatcher.match(uri)) {
		case WORDS_ALL_ROWS:
			return Contract.Dictionary.CONTENT_TYPE;
		case WORDS_SINGLE_ROW:
			return Contract.Dictionary.CONTENT_TYPE_ITEM;
		default:
			throw new IllegalArgumentException("Unsupported URI: " + uri);
		}
	}

	@Override
	public Uri insert(Uri uri, ContentValues values) {
		String table = null;
		switch (uriMatcher.match(uri)) {
		case WORDS_ALL_ROWS:
			table = Contract.Dictionary.TABLE_NAME;
			break;
		default:
			throw new IllegalArgumentException("Unsupported uri: " + uri);
		}
		SQLiteDatabase db = mDatabaseHelper.getWritableDatabase();
		long id = db.insert(table, null, values);
		Uri insertedUri = ContentUris.withAppendedId(uri, id);
		getContext().getContentResolver().notifyChange(insertedUri, null);
		return insertedUri;
	}

	@Override
	public Cursor query(Uri uri, String[] projection, String selection,
			String[] selectionArgs, String sortOrder) {
		SQLiteQueryBuilder query = new SQLiteQueryBuilder();
		switch (uriMatcher.match(uri)) {
		case WORDS_SINGLE_ROW:
			long id = ContentUris.parseId(uri);
			query.appendWhere(Contract.Dictionary.COLUMN_ID + "=" + id);
		case WORDS_ALL_ROWS:
			query.setTables(Contract.Dictionary.TABLE_NAME);
			break;
		default:
			throw new IllegalArgumentException("Unsupported uri: " + uri);
		}
		SQLiteDatabase db = mDatabaseHelper.getWritableDatabase();
		Cursor cursor = query.query(db, projection, selection, selectionArgs,
				null, null, sortOrder);
		cursor.setNotificationUri(getContext().getContentResolver(), uri);
		return cursor;
	}

	@Override
	public int update(Uri uri, ContentValues values, String selection,
			String[] selectionArgs) {
		throw new UnsupportedOperationException();
	}

}
