package cz.cvut.and.tutorial06;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import android.app.ListActivity;
import android.content.ContentUris;
import android.content.ContentValues;
import android.database.Cursor;
import android.os.Bundle;
import android.os.Environment;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;

public class Tutorial06Activity extends ListActivity {
	private static final String TAG = "Tutorial06Activity";
	private static final String EXPORT_FILE_NAME = "export.csv";

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		final EditText editWord = (EditText) findViewById(R.id.editWord);
		final EditText editDefinition = (EditText) findViewById(R.id.editDefinition);

		Button add = (Button) findViewById(R.id.btnAdd);
		add.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				addToDictionary(editWord.getText().toString(), editDefinition
						.getText().toString());
				editWord.setText("");
				editDefinition.setText("");
			}
		});

		Cursor cursor = getDictionaryCursor();
		setListAdapter(new SimpleCursorAdapter(this,
				android.R.layout.two_line_list_item, cursor, new String[] {
						Contract.Dictionary.COLUMN_WORD,
						Contract.Dictionary.COLUMN_DEFINITION }, new int[] {
						android.R.id.text1, android.R.id.text2 }));
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		((SimpleCursorAdapter) getListAdapter()).changeCursor(null);
	}

	@Override
	protected void onListItemClick(ListView l, View v, int position, long id) {
		getContentResolver()
				.delete(ContentUris.withAppendedId(
						Contract.Dictionary.CONTENT_URI, id), null, null);
	}

	public Cursor getDictionaryCursor() {
		return managedQuery(Contract.Dictionary.CONTENT_URI, null, null, null,
				null);
	}

	private void addToDictionary(String key, String definition) {
		ContentValues values = new ContentValues();
		values.put(Contract.Dictionary.COLUMN_WORD, key);
		values.put(Contract.Dictionary.COLUMN_DEFINITION, definition);
		getContentResolver().insert(Contract.Dictionary.CONTENT_URI, values);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.menu, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.export:
			exportToExternalStorageFile();

			return true;
		default:
			return super.onOptionsItemSelected(item);
		}

	}

	public void exportToExternalStorageFile() {
		Cursor cursor = getDictionaryCursor();

		int wordColumn = cursor.getColumnIndex(Contract.Dictionary.COLUMN_WORD);
		int definitionColumn = cursor
				.getColumnIndex(Contract.Dictionary.COLUMN_DEFINITION);

		File dir = getExternalFilesDir();
		dir.mkdirs();
		File exportFile = new File(dir, EXPORT_FILE_NAME);
		try {
			Log.d(TAG, exportFile + "");
			exportFile.createNewFile();
			FileWriter fileWriter = new FileWriter(exportFile);
			while (cursor.moveToNext()) {
				fileWriter.append(cursor.getString(wordColumn) + ";"
						+ cursor.getString(definitionColumn) + "\n");
			}
			fileWriter.flush();
			fileWriter.close();
			cursor.close();
		} catch (IOException e) {
			Log.w(TAG, "IOException: " + exportFile);
		}
	}

	public File getExternalFilesDir() {
		String packageName = getPackageName();
		File externalPath = Environment.getExternalStorageDirectory();
		return new File(externalPath.getAbsolutePath() + "/Android/data/"
				+ packageName + "/files");
	}
}
